﻿param($installPath, $toolsPath, $package, $project)

$analyzersPaths = Join-Path (Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers" ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                try
                {
                    $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
                }
                catch
                {

                }
            }
        }
    }
}
# SIG # Begin signature block
# MIIqDQYJKoZIhvcNAQcCoIIp/jCCKfoCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCA0o1Q2Ssh45kim
# Q4Z6GSL/ZYYQ36aRIydIY6BR1mJeQaCCDlkwggawMIIEmKADAgECAhAIrUCyYNKc
# TJ9ezam9k67ZMA0GCSqGSIb3DQEBDAUAMGIxCzAJBgNVBAYTAlVTMRUwEwYDVQQK
# EwxEaWdpQ2VydCBJbmMxGTAXBgNVBAsTEHd3dy5kaWdpY2VydC5jb20xITAfBgNV
# BAMTGERpZ2lDZXJ0IFRydXN0ZWQgUm9vdCBHNDAeFw0yMTA0MjkwMDAwMDBaFw0z
# NjA0MjgyMzU5NTlaMGkxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwg
# SW5jLjFBMD8GA1UEAxM4RGlnaUNlcnQgVHJ1c3RlZCBHNCBDb2RlIFNpZ25pbmcg
# UlNBNDA5NiBTSEEzODQgMjAyMSBDQTEwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAw
# ggIKAoICAQDVtC9C0CiteLdd1TlZG7GIQvUzjOs9gZdwxbvEhSYwn6SOaNhc9es0
# JAfhS0/TeEP0F9ce2vnS1WcaUk8OoVf8iJnBkcyBAz5NcCRks43iCH00fUyAVxJr
# Q5qZ8sU7H/Lvy0daE6ZMswEgJfMQ04uy+wjwiuCdCcBlp/qYgEk1hz1RGeiQIXhF
# LqGfLOEYwhrMxe6TSXBCMo/7xuoc82VokaJNTIIRSFJo3hC9FFdd6BgTZcV/sk+F
# LEikVoQ11vkunKoAFdE3/hoGlMJ8yOobMubKwvSnowMOdKWvObarYBLj6Na59zHh
# 3K3kGKDYwSNHR7OhD26jq22YBoMbt2pnLdK9RBqSEIGPsDsJ18ebMlrC/2pgVItJ
# wZPt4bRc4G/rJvmM1bL5OBDm6s6R9b7T+2+TYTRcvJNFKIM2KmYoX7BzzosmJQay
# g9Rc9hUZTO1i4F4z8ujo7AqnsAMrkbI2eb73rQgedaZlzLvjSFDzd5Ea/ttQokbI
# YViY9XwCFjyDKK05huzUtw1T0PhH5nUwjewwk3YUpltLXXRhTT8SkXbev1jLchAp
# QfDVxW0mdmgRQRNYmtwmKwH0iU1Z23jPgUo+QEdfyYFQc4UQIyFZYIpkVMHMIRro
# OBl8ZhzNeDhFMJlP/2NPTLuqDQhTQXxYPUez+rbsjDIJAsxsPAxWEQIDAQABo4IB
# WTCCAVUwEgYDVR0TAQH/BAgwBgEB/wIBADAdBgNVHQ4EFgQUaDfg67Y7+F8Rhvv+
# YXsIiGX0TkIwHwYDVR0jBBgwFoAU7NfjgtJxXWRM3y5nP+e6mK4cD08wDgYDVR0P
# AQH/BAQDAgGGMBMGA1UdJQQMMAoGCCsGAQUFBwMDMHcGCCsGAQUFBwEBBGswaTAk
# BggrBgEFBQcwAYYYaHR0cDovL29jc3AuZGlnaWNlcnQuY29tMEEGCCsGAQUFBzAC
# hjVodHRwOi8vY2FjZXJ0cy5kaWdpY2VydC5jb20vRGlnaUNlcnRUcnVzdGVkUm9v
# dEc0LmNydDBDBgNVHR8EPDA6MDigNqA0hjJodHRwOi8vY3JsMy5kaWdpY2VydC5j
# b20vRGlnaUNlcnRUcnVzdGVkUm9vdEc0LmNybDAcBgNVHSAEFTATMAcGBWeBDAED
# MAgGBmeBDAEEATANBgkqhkiG9w0BAQwFAAOCAgEAOiNEPY0Idu6PvDqZ01bgAhql
# +Eg08yy25nRm95RysQDKr2wwJxMSnpBEn0v9nqN8JtU3vDpdSG2V1T9J9Ce7FoFF
# UP2cvbaF4HZ+N3HLIvdaqpDP9ZNq4+sg0dVQeYiaiorBtr2hSBh+3NiAGhEZGM1h
# mYFW9snjdufE5BtfQ/g+lP92OT2e1JnPSt0o618moZVYSNUa/tcnP/2Q0XaG3Ryw
# YFzzDaju4ImhvTnhOE7abrs2nfvlIVNaw8rpavGiPttDuDPITzgUkpn13c5Ubdld
# AhQfQDN8A+KVssIhdXNSy0bYxDQcoqVLjc1vdjcshT8azibpGL6QB7BDf5WIIIJw
# 8MzK7/0pNVwfiThV9zeKiwmhywvpMRr/LhlcOXHhvpynCgbWJme3kuZOX956rEnP
# LqR0kq3bPKSchh/jwVYbKyP/j7XqiHtwa+aguv06P0WmxOgWkVKLQcBIhEuWTatE
# QOON8BUozu3xGFYHKi8QxAwIZDwzj64ojDzLj4gLDb879M4ee47vtevLt/B3E+bn
# KD+sEq6lLyJsQfmCXBVmzGwOysWGw/YmMwwHS6DTBwJqakAwSEs0qFEgu60bhQji
# WQ1tygVQK+pKHJ6l/aCnHwZ05/LWUpD9r4VIIflXO7ScA+2GRfS0YW6/aOImYIbq
# yK+p/pQd52MbOoZWeE4wggehMIIFiaADAgECAhALyko14sGCglkXWPsT8gmbMA0G
# CSqGSIb3DQEBCwUAMGkxCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5EaWdpQ2VydCwg
# SW5jLjFBMD8GA1UEAxM4RGlnaUNlcnQgVHJ1c3RlZCBHNCBDb2RlIFNpZ25pbmcg
# UlNBNDA5NiBTSEEzODQgMjAyMSBDQTEwHhcNMjExMjI4MDAwMDAwWhcNMjMwMTAz
# MjM1OTU5WjCB9jEdMBsGA1UEDwwUUHJpdmF0ZSBPcmdhbml6YXRpb24xEzARBgsr
# BgEEAYI3PAIBAxMCVVMxGTAXBgsrBgEEAYI3PAIBAhMIRGVsYXdhcmUxEDAOBgNV
# BAUTBzQxNTI5NTQxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
# DgYDVQQHEwdTZWF0dGxlMSIwIAYDVQQKExlBbWF6b24gV2ViIFNlcnZpY2VzLCBJ
# bmMuMRcwFQYDVQQLEw5TREtzIGFuZCBUb29sczEiMCAGA1UEAxMZQW1hem9uIFdl
# YiBTZXJ2aWNlcywgSW5jLjCCAaIwDQYJKoZIhvcNAQEBBQADggGPADCCAYoCggGB
# AKHRLdQSyJ6AfhQ8U7Gi6le7gshUhu34xQ7jaTCfpKaKQRGu+oNfAYDRSSfh498e
# K+jFnGHU/TMzVHEgBb4TUrc1e2f5LHhXAtYTJK0uis9OJ5n3MjHwOJt/uGSSMUAI
# IIselvbSF2mOE0lIz0CNMIlUiXI9O+y9+FJP7Vsg/NU/zAVsQ4Ok0GLd+Yp566nR
# uj9aNU+L+TxRhSHA7KKjJ9oE0mVblUGQaeNrOd1Ql9djJy0pg6oT2s9Peh8lqB3t
# UsMaoQ/FMV0P/e1S6V3yFg/I1OvQdtm29ryJTdg9ZvIV/FGnIYdW5s5T8t//nf+7
# LToQVhpML/ZWEhFRAa6We80Y8zs9glIPDZyYmi6OPbpY7kVHa4dr8S49tPwrVMjC
# 3hk9v9S6poDx/hR9kytwVt1Lo4LjAlpmKLeHVmOnn5uenpXqFOJMbTMYmciwHz8y
# WJwZYMKKLJPCGa79xaAkZj9HCop5yPUPccqjyz2i0v/Pt8yFH77s8q86e99O2a+/
# oQIDAQABo4ICNTCCAjEwHwYDVR0jBBgwFoAUaDfg67Y7+F8Rhvv+YXsIiGX0TkIw
# HQYDVR0OBBYEFGmlIp+0bnVEmnOvWcJjnCup9DbsMC4GA1UdEQQnMCWgIwYIKwYB
# BQUHCAOgFzAVDBNVUy1ERUxBV0FSRS00MTUyOTU0MA4GA1UdDwEB/wQEAwIHgDAT
# BgNVHSUEDDAKBggrBgEFBQcDAzCBtQYDVR0fBIGtMIGqMFOgUaBPhk1odHRwOi8v
# Y3JsMy5kaWdpY2VydC5jb20vRGlnaUNlcnRUcnVzdGVkRzRDb2RlU2lnbmluZ1JT
# QTQwOTZTSEEzODQyMDIxQ0ExLmNybDBToFGgT4ZNaHR0cDovL2NybDQuZGlnaWNl
# cnQuY29tL0RpZ2lDZXJ0VHJ1c3RlZEc0Q29kZVNpZ25pbmdSU0E0MDk2U0hBMzg0
# MjAyMUNBMS5jcmwwPQYDVR0gBDYwNDAyBgVngQwBAzApMCcGCCsGAQUFBwIBFhto
# dHRwOi8vd3d3LmRpZ2ljZXJ0LmNvbS9DUFMwgZQGCCsGAQUFBwEBBIGHMIGEMCQG
# CCsGAQUFBzABhhhodHRwOi8vb2NzcC5kaWdpY2VydC5jb20wXAYIKwYBBQUHMAKG
# UGh0dHA6Ly9jYWNlcnRzLmRpZ2ljZXJ0LmNvbS9EaWdpQ2VydFRydXN0ZWRHNENv
# ZGVTaWduaW5nUlNBNDA5NlNIQTM4NDIwMjFDQTEuY3J0MAwGA1UdEwEB/wQCMAAw
# DQYJKoZIhvcNAQELBQADggIBALlYa6PSDPPulVJbqEi7XGz23lFZwYa1PiXk+PkJ
# O2HDXv2zep26LZriwBHT2yA/KbDvbwZpf4VOBKn5lQC9R+DsgwW/xZbNq7y3cWf9
# Ad1AQ9Do/FXfBqVO1if+GpqFbqUme5wOjn8/8dc4nFR4erbDgkM4ICn/astBigYn
# fM5wTO+J8ex+7fE2D1kFAwfZAuiRNdDreVMDlYXpJMQ4CtTKVLHYentLR747zzRj
# O4PqgL1exvbvpOMZlSDLWhaDjtKwUDb645ziHDA3DXe8K51+hIFuadKTinJa8Pfs
# bgg2W7aTfBdi2gTyXkeVJ836631Ks4KD3cXui9Jx2PWRAVxKIEvXuebZ09Mph2ji
# BH75urqS57i1mpS7OA5lIj7a7NIYsVl26PVpJUEr3LRKV8GO3tRC7KP0zE7sB7k2
# VQKwBXbsifq/vpcmeyy4OeQbZ1i8GwZLPHuygP9exTWK2o2wWByJs62Wdk6JmSRE
# vr9Wr59BVNbQfRSRaF9q058bBK68hGZtDBpJ9gJX4V12DI2UpSbcGf10+afL1J4z
# FDv98GIGkgmfLQJUpJeC/FnNrEXJbINndCsOb6gdLvLX1grMdUPmPkpRZyvG3HEy
# EMCV5ODMItTx7K6TDyeZDIXXP5oBnBMK9EjtRD3XkEb9dDfuzCrdlTpEoTElt2mG
# uEE7MYIbCjCCGwYCAQEwfTBpMQswCQYDVQQGEwJVUzEXMBUGA1UEChMORGlnaUNl
# cnQsIEluYy4xQTA/BgNVBAMTOERpZ2lDZXJ0IFRydXN0ZWQgRzQgQ29kZSBTaWdu
# aW5nIFJTQTQwOTYgU0hBMzg0IDIwMjEgQ0ExAhALyko14sGCglkXWPsT8gmbMA0G
# CWCGSAFlAwQCAQUAoHwwEAYKKwYBBAGCNwIBDDECMAAwGQYJKoZIhvcNAQkDMQwG
# CisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZI
# hvcNAQkEMSIEIORYtAjFMQ3gCzLzBJgwl7H6t5HinNPpAt7n8yYK3fwtMA0GCSqG
# SIb3DQEBAQUABIIBgJbWqFvtRi88Ka7nLRJjxOjQRiRzbHtnxcpR26nJlZqESzRr
# QaWGVw45UGkgWDJx/GATWt4ICk0OVrhQSqNuDeiGmmiJWu+dnBZkuxp98vuOiGN+
# fnQNx/oNkYmVUgzGJWGkHI+G5okHnBFOXNgp0x8a95PpyxRCA2p9q/aKg0lexDYx
# W2sCK4c8PEdl0Tl+t/g31O9LjurWVoGEHGhUnv8xtKV6/Udn0eC42b4vHlqUZ27e
# jubP9ElSVZA/p8CevxqY4dbMBKZ1J9mRRyYJRQdT+YvNRTmNogvYyiTjKFSnokqO
# Z6ueA5/esCegYnnAQ5T5c7nrlSjvcwqUgBfQoMZhAGv4vVSdZQgZ9zvcITORYOck
# fy+R7g/BY9aFT2lGagEFlXH6e7a0jodMEWVgApyFS+6cdJFRKSWnEUr/Mwzhw/JA
# bU7+Lgh8q2i9fotQUT081jDE5g9mjEp/EkfBg7icPzHxZ6vyvl8pbHDshvD3T1Y+
# TOmHDhEXR5apmmt61aGCGGAwghhcBgorBgEEAYI3AwMBMYIYTDCCGEgGCSqGSIb3
# DQEHAqCCGDkwghg1AgEDMQ0wCwYJYIZIAWUDBAIDMIH0BgsqhkiG9w0BCRABBKCB
# 5ASB4TCB3gIBAQYKYIZIAYb6bAoDBTAxMA0GCWCGSAFlAwQCAQUABCBuu9zdAEcP
# bYfgYsnfpqNZQGJJubfjoPvciSZMkMx7+QIJAIC7ngjDULIjGA8yMDIyMDcwNTE4
# NDczNlowAwIBAaB5pHcwdTELMAkGA1UEBhMCQ0ExEDAOBgNVBAgTB09udGFyaW8x
# DzANBgNVBAcTBk90dGF3YTEWMBQGA1UEChMNRW50cnVzdCwgSW5jLjErMCkGA1UE
# AxMiRW50cnVzdCBUaW1lc3RhbXAgQXV0aG9yaXR5IC0gVFNBMqCCEw4wggXfMIIE
# x6ADAgECAhBOQOQ3VO3mjAAAAABR05R/MA0GCSqGSIb3DQEBCwUAMIG+MQswCQYD
# VQQGEwJVUzEWMBQGA1UEChMNRW50cnVzdCwgSW5jLjEoMCYGA1UECxMfU2VlIHd3
# dy5lbnRydXN0Lm5ldC9sZWdhbC10ZXJtczE5MDcGA1UECxMwKGMpIDIwMDkgRW50
# cnVzdCwgSW5jLiAtIGZvciBhdXRob3JpemVkIHVzZSBvbmx5MTIwMAYDVQQDEylF
# bnRydXN0IFJvb3QgQ2VydGlmaWNhdGlvbiBBdXRob3JpdHkgLSBHMjAeFw0yMTA1
# MDcxNTQzNDVaFw0zMDExMDcxNjEzNDVaMGkxCzAJBgNVBAYTAlVTMRYwFAYDVQQK
# DA1FbnRydXN0LCBJbmMuMUIwQAYDVQQDDDlFbnRydXN0IENvZGUgU2lnbmluZyBS
# b290IENlcnRpZmljYXRpb24gQXV0aG9yaXR5IC0gQ1NCUjEwggIiMA0GCSqGSIb3
# DQEBAQUAA4ICDwAwggIKAoICAQCngY/3FEW2YkPy2K7TJV5IT1G/xX2fUBw10dZ+
# YSqUGW0nRqSmGl33VFFqgCLGqGZ1TVSDyV5oG6v2W2Swra0gvVTvRmttAudFrnX2
# joq5Mi6LuHccUk15iF+lOhjJUCyXJy2/2gB9Y3/vMuxGh2Pbmp/DWiE2e/mb1cqg
# bnIs/OHxnnBNCFYVb5Cr+0i6udfBgniFZS5/tcnA4hS3NxFBBuKK4Kj25X62eAUB
# w2DtTwdBLgoTSeOQm3/dvfqsv2RR0VybtPVc51z/O5uloBrXfQmywrf/bhy8yH3m
# 6Sv8crMU6UpVEoScRCV1HfYq8E+lID1oJethl3wP5bY9867DwRG8G47M4EcwXkIA
# hnHjWKwGymUfe5SmS1dnDH5erXhnW1XjXuvH2OxMbobL89z4n4eqclgSD32m+PhC
# OTs8LOQyTUmM4OEAwjignPqEPkHcblauxhpb9GdoBQHNG7+uh7ydU/Yu6LZr5Jne
# xU+HWKjSZR7IH9Vybu5ZHFc7CXKd18q3kMbNe0WSkUIDTH0/yvKquMIOhvMQn0Yu
# pGaGaFpoGHApOBGAYGuKQ6NzbOOzazf/5p1nAZKG3y9I0ftQYNVc/iHTAUJj/u9w
# tBfAj6ju08FLXxLq/f0uDodEYOOp9MIYo+P9zgyEIg3zp3jak/PbOM+5LzPG/wc8
# Xr5F0wIDAQABo4IBKzCCAScwDgYDVR0PAQH/BAQDAgGGMBIGA1UdEwEB/wQIMAYB
# Af8CAQEwHQYDVR0lBBYwFAYIKwYBBQUHAwMGCCsGAQUFBwMIMDsGA1UdIAQ0MDIw
# MAYEVR0gADAoMCYGCCsGAQUFBwIBFhpodHRwOi8vd3d3LmVudHJ1c3QubmV0L3Jw
# YTAzBggrBgEFBQcBAQQnMCUwIwYIKwYBBQUHMAGGF2h0dHA6Ly9vY3NwLmVudHJ1
# c3QubmV0MDAGA1UdHwQpMCcwJaAjoCGGH2h0dHA6Ly9jcmwuZW50cnVzdC5uZXQv
# ZzJjYS5jcmwwHQYDVR0OBBYEFIK61j2Xzp/PceiSN6/9s7VpNVfPMB8GA1UdIwQY
# MBaAFGpyJnrQHu995ztpUdRsjZ+QEmarMA0GCSqGSIb3DQEBCwUAA4IBAQAfXkEE
# toNwJFMsVXMdZTrA7LR7BJheWTgTCaRZlEJeUL9PbG4lIJCTWEAN9Rm0Yu4kXsIB
# WBUCHRAJb6jU+5J+Nzg+LxR9jx1DNmSzZhNfFMylcfdbIUvGl77clfxwfREc0yHd
# 0CQ5KcX+Chqlz3t57jpv3ty/6RHdFoMI0yyNf02oFHkvBWFSOOtg8xRofcuyiq3A
# lFzkJg4sit1Gw87kVlHFVuOFuE2bRXKLB/GK+0m4X9HyloFdaVIk8Qgj0tYjD+uL
# 136LwZNr+vFie1jpUJuXbheIDeHGQ5jXgWG2hZ1H7LGerj8gO0Od2KIc4NR8CMKv
# dgb4YmZ6tvf6yK81MIIGbzCCBFegAwIBAgIQJbwr8ynKEH8eqbqIhdSdOzANBgkq
# hkiG9w0BAQ0FADBpMQswCQYDVQQGEwJVUzEWMBQGA1UECgwNRW50cnVzdCwgSW5j
# LjFCMEAGA1UEAww5RW50cnVzdCBDb2RlIFNpZ25pbmcgUm9vdCBDZXJ0aWZpY2F0
# aW9uIEF1dGhvcml0eSAtIENTQlIxMB4XDTIxMDUwNzE5MjIxNFoXDTQwMTIyOTIz
# NTkwMFowTjELMAkGA1UEBhMCVVMxFjAUBgNVBAoTDUVudHJ1c3QsIEluYy4xJzAl
# BgNVBAMTHkVudHJ1c3QgVGltZSBTdGFtcGluZyBDQSAtIFRTMjCCAiIwDQYJKoZI
# hvcNAQEBBQADggIPADCCAgoCggIBALUDKga2hE80zJ4xvuqOxntuICQPA9e9gTYz
# 5m/SPrvEnqqgzGZdQmA0UeItYYO6PJ5ouEvDZo6l3iu6my1Bpd7Qy1cFLYjZwEaI
# bTw1DRmQrLgMGfBMxdtFW9w7wryNRADgOP//XcjPCJo91LLre5XDxKUA4GIBZFlf
# jON7i6n5RbfGsKIKN0O4RoGrhn5/L97wX+vNIMylLTHjqC6Zm+B43fTbXYJjfTA5
# iH4kBuZ8YIR4yFwp5ZXL9XtPz1jckM+nonsUVMTgN5gwwZu2rpwp9mslQ+cSaj4Z
# i77A54HXSjAIfnyN3zzzSJMh3oGDap0APtdgutGzYgiW6bZJADj0XHYN2ndqPaCV
# 3h6hzFl6Xp/P6XZdQPK1FbVgaCzzWskjg9j1GmtpKKS21K5iBt4mRb3e6VZ3qtxk
# sEHNzBPxXXF0spQIS08ybn5wuHfp1TI3wnreQhLocRzi2GK/qmtBhgZb5mm+Jgn0
# l8L+TPSAcoRu297FB6mOFaJt4RvgCQ/1oAegu8R3cwk8B5ONAbUSZy1NGbW4xckQ
# q3DPQv+lJx3WEtbkGERg+zldhLtmtVMSnQMUgmUptOxJcv2zQ+XDAikkuh/4uL5d
# o7cuqfzPYtn6l8QTeONVuVp6hOv/u89piMC2+YtghUEQUMcFENJedp0+Nez2T4r5
# Ens/rws3AgMBAAGjggEsMIIBKDASBgNVHRMBAf8ECDAGAQH/AgEAMB0GA1UdDgQW
# BBQmD/DESAgbzd2R9VRUtrOz/JnxCDAfBgNVHSMEGDAWgBSCutY9l86fz3Hokjev
# /bO1aTVXzzAzBggrBgEFBQcBAQQnMCUwIwYIKwYBBQUHMAGGF2h0dHA6Ly9vY3Nw
# LmVudHJ1c3QubmV0MDEGA1UdHwQqMCgwJqAkoCKGIGh0dHA6Ly9jcmwuZW50cnVz
# dC5uZXQvY3NicjEuY3JsMA4GA1UdDwEB/wQEAwIBhjATBgNVHSUEDDAKBggrBgEF
# BQcDCDBFBgNVHSAEPjA8MDAGBFUdIAAwKDAmBggrBgEFBQcCARYaaHR0cDovL3d3
# dy5lbnRydXN0Lm5ldC9ycGEwCAYGZ4EMAQQCMA0GCSqGSIb3DQEBDQUAA4ICAQB2
# PUZohV8JwM7J+Me4136nXDsLRnPOIlOLOPYRunfEwochjyfZDJXr6EvlXNeQFW+o
# KiyKauAiETR5+r2Wech2Fs2xROpxUQ+bVckYfNWCeZzzpreTqQU4cgIGl6Gosnl+
# Xgjibmx5mqiHlM5/j1U2QA+fP1HVZr57q4bmboe6TmNdsdiOH8tnww1w2nrrk7IU
# hNI+fZM/Fgw2oFx5AJ8LbuWEKtiIwW0Etzfzkppw4DsD/c27J4LOL/yN5LLKvvgl
# hcbtdMg9NV84CT15T+sb4EFepXSBP1EVwPhJiI+6uwXUrUWCM3nBJY1fVD2R5Lif
# F5gAXa0o5U9fG/v4VLWlxCT88HY7+A1ezEewyqq7blHfU7VJGvFgh7f5/WkGdV9z
# 1hGQ8oBYjuXDDwOYjARTsymH3z/3sOlMV4EkRHlo/hs2B9ZlPexv1sK1qmF8Zgbs
# 0uVpgPhxki5c4hFGGEVL1voFZO+73gbKQyW9343JAXRhiNvwx6Y94wxxvH9L58jg
# buDagPkAnsBrJdWjulwr/sRgIBRKByMx5RrLkUSymntD8VuYtSFLuDE7IlTueWH3
# mpQbZicqxt/hZV3vcTnmUCX9hzS5rl18JzvnZZP4KISxb4aTLJOTtnCvoe7IpGGp
# hDv7Crf4uG0m7kdO9V4F+pwPEX3Xy5GuQyD3FVljvDCCBrQwggScoAMCAQICEHTZ
# 8ttRPCJn/UecNgc/ex0wDQYJKoZIhvcNAQENBQAwTjELMAkGA1UEBhMCVVMxFjAU
# BgNVBAoTDUVudHJ1c3QsIEluYy4xJzAlBgNVBAMTHkVudHJ1c3QgVGltZSBTdGFt
# cGluZyBDQSAtIFRTMjAeFw0yMTA1MTQwMDAwMDBaFw0zMjA4MTQwMDAwMDBaMHUx
# CzAJBgNVBAYTAkNBMRAwDgYDVQQIEwdPbnRhcmlvMQ8wDQYDVQQHEwZPdHRhd2Ex
# FjAUBgNVBAoTDUVudHJ1c3QsIEluYy4xKzApBgNVBAMTIkVudHJ1c3QgVGltZXN0
# YW1wIEF1dGhvcml0eSAtIFRTQTIwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIK
# AoICAQCvvyxGvGsxsCZ/Aqb4cOtkluhKGikMQVzgHEqluYIzk6bOVgYflJ6pUQIZ
# jbvyD57bidAzhFjjDqDe+VJBILxg1wthp09vQkxwnJwpIwvCp8Jc3Z64LPNeuEG5
# SMozcDQTdfdQXm0mbsUUMzEXzYG7uhJQoKzBewWDchBvKUP8G2kvxcLrhdeDlWAI
# I3XfXCL/pIEG0c7wt1wcTpmwqKQdgONwPNh5XsPJCQfZM5I1liFJf9TreNL4p/ML
# uUqAETWpLNhCm7ZumKtQw1ChLfbd8qcxnxsLZ1Uznhh7zGILlNQj06XpuiljESVm
# Z5Rb/zt5OLDTLRZ1ifTzeJBav2t+F6qDpPFQgZyC3B7KYrF1D4i/DRd6Cu0DxA2P
# te8sJdWIlOdcFtN4T7LyNHtZSRjPyoPcUAC+Im/KVLwmJyc6p63KOD4Mr6gh7ZVy
# 6NXSe3gS8Z5i2f4C36C7yX7wZGzI2K1D5CnNZ7ybTQVuc64eDHSDoNfxqNETusaT
# 3RHuBKNZYQ2iASRXFj8zBGRqBgfXaVbximSpGD8JsAw8B/UKP5nUhecPl8HRK8Md
# rofbcnUY85t2VUAJx1WcLEZHp9pMo5wR7+F0VHd7eMC2FOLP2pzURl3Q1gqTHwEn
# 59j8wwps33ytTx2Qs9aOJ+imv0tGcWY6xvlo6UT6eQcGTe8bvQIDAQABo4IBZTCC
# AWEwDAYDVR0TAQH/BAIwADAdBgNVHQ4EFgQUwvXRFsHNva14YVTOCBRu9gEPvmYw
# HwYDVR0jBBgwFoAUJg/wxEgIG83dkfVUVLazs/yZ8QgwaAYIKwYBBQUHAQEEXDBa
# MCMGCCsGAQUFBzABhhdodHRwOi8vb2NzcC5lbnRydXN0Lm5ldDAzBggrBgEFBQcw
# AoYnaHR0cDovL2FpYS5lbnRydXN0Lm5ldC90czItY2hhaW4yNTYuY2VyMDEGA1Ud
# HwQqMCgwJqAkoCKGIGh0dHA6Ly9jcmwuZW50cnVzdC5uZXQvdHMyY2EuY3JsMA4G
# A1UdDwEB/wQEAwIHgDAWBgNVHSUBAf8EDDAKBggrBgEFBQcDCDBMBgNVHSAERTBD
# MDcGCmCGSAGG+mwKAwUwKTAnBggrBgEFBQcCARYbaHR0cHM6Ly93d3cuZW50cnVz
# dC5uZXQvcnBhMAgGBmeBDAEEAjANBgkqhkiG9w0BAQ0FAAOCAgEAdSKLU8Bxl05K
# Ba1NDg4rlEDivKf7o2glxK1QZzXLFLx0lmB5/+Gxew8/aOvyhvkdPU9Xui7IJ9On
# uyeLk+PqGM9RLH+iOsWf4JsAK3Qo8pbg9MIahFi255CLxexJBrzoEQQUltW/3Z6d
# SjCv4crma6gE0qunkSKvzfxmWX9aJmO6Z0CGKIvs3Y4jujhA3MML1j9CjvnOAmgz
# i0uoG+aZpmxeHGuNjeQva4BNDc+SYmJ41gvBXIG67M07jotbrmsA27gcnzDImQKN
# DRpwWTP/2J+8EFCkwMAV+y/aBGPsOTqCvcUnS2SCtV0PcOd80lUVyDYStf7yWghk
# moPwyYtpPPq5cj7LT9eJcgwTF0BSOrn4EBJN5OgtWtXY+syZAYJM0hQv3WVmzjEC
# L17ZPF+T4ZKcuNZVrQ60r+v1M782F2G0NDZ47PYKjXKDdBUTvAh2G8v8Fp1g/6b/
# CJv8eVMidrJCNtmOJ/d48OFzfzBqsLBkZ9a7AU+NeHp3tsF9fX966FTk967a9Egw
# efvmKGO9fBzp97O0tXYPecTV7WETG3FGlh1m3hKmah8dq7Vu/1geR5D/6mU6SB0L
# IEmFIkd0tgGisLnf4IbtU92Ypi2u4b0oRybnbTMaIoerx/7zG2oEyLnf27L7Pdua
# I8lznl/H2FyiBJsSwaqijhv8FBGSbdwxggQWMIIEEgIBATBiME4xCzAJBgNVBAYT
# AlVTMRYwFAYDVQQKEw1FbnRydXN0LCBJbmMuMScwJQYDVQQDEx5FbnRydXN0IFRp
# bWUgU3RhbXBpbmcgQ0EgLSBUUzICEHTZ8ttRPCJn/UecNgc/ex0wCwYJYIZIAWUD
# BAIDoIIBiTAaBgkqhkiG9w0BCQMxDQYLKoZIhvcNAQkQAQQwHAYJKoZIhvcNAQkF
# MQ8XDTIyMDcwNTE4NDczNlowKQYJKoZIhvcNAQk0MRwwGjALBglghkgBZQMEAgOh
# CwYJKoZIhvcNAQENME8GCSqGSIb3DQEJBDFCBEDgR4t6OHrQJeibEtaBlCV/Hp5M
# 1hY58mTGg5B76PY5vnLgPnrWndSxZzZ1WDf/VS8iGF/eFExnW87SWv+uvyaTMIHQ
# BgsqhkiG9w0BCRACLzGBwDCBvTCBujCBtzALBglghkgBZQMEAgMEQGB5Xy0WxpxZ
# /aHeWWOtz+OkiBS2XOgRS9W/7g8SuzzwVjHkJBS5GbjBMdarreVC14LIijGQZS9L
# CvzyGRHJN4wwZjBSpFAwTjELMAkGA1UEBhMCVVMxFjAUBgNVBAoTDUVudHJ1c3Qs
# IEluYy4xJzAlBgNVBAMTHkVudHJ1c3QgVGltZSBTdGFtcGluZyBDQSAtIFRTMgIQ
# dNny21E8Imf9R5w2Bz97HTALBgkqhkiG9w0BAQ0EggIAZ+iUIihJ9x06UuD+e6nk
# LWkvl1XGUBLirO8JK1eSSIIgp+elyWbwzssMoIaWEKcH8Qkpn186XxKhpo9YvupI
# 5rcu1MTwwWdlmc3JHi1xqwuxpjdR2nKs/D8bbxkkcffZygVQFYeYXNtuwt2wLwVR
# AlT3aDHwXszv6vhe9hnDjbg1/UuoZolHzi/cF/4+lHan73UUbPAKQeo/ZMHLsqcQ
# XxAfqIs3UwpgR1Gzy9Mu1uU3sZBe0ZwuFbRJYubxe2cROzKZTgnjOL4rXjU82xVO
# PnHhQqn90um4cz/JyiOw1nD10EpFL4mqlieDzDlY6Y5bDJtIbTyTouQcPCyZtzO7
# x+FaGpqvUurqzNFLDKxWhdkp5yamZcalMIK14PwKk6KhyYDmFDsskIE5UhD/oZmL
# NoH8stTcZ4s+AiOe3OXyuIsoe9rjfbOcJJHl1N3TothxiAhQRZmH2t2jixXfYjhm
# s67Ff0H29sy5CJL49LOJNG/xwLIgT1CnPQPFBX3PHBK1sGfwtRuiLUZEQgmcSiGx
# bV9g3v7YzuJrzCrMHbOCYBlkjN+OazpeLPlQIdRXvBds0d/F7bjNq68WGM2s7AnC
# +tdsfXW/TK1b73fHlThQAxqC2rQMV+pUQouE8VwW7Oh222zHRRKfI1e/cqop9H2g
# Bpa9CcYMwuSBrUKJd9cNmb0=
# SIG # End signature block
